@@ -1,7 +1,9 @@
 import os
+import shutil
 import subprocess
 
 from .base import BasePackager
+from .channel import PackagerChannel
 from .render import Renderer
 from .exceptions import DestinationExists
 
@@ -13,18 +15,48 @@ class PackageCreator(BasePackager):
         super(PackageCreator, self).__init__(**kwargs)
         self.template_dir = self.settings['template']['dir']
         self.renderer = Renderer(self.settings)
+        self.channel = PackagerChannel(self.settings)
 
-    def copy_skeleton(self, destination, context):
+    def create(self, package_name, destination):
         if os.path.exists(destination):
-            raise DestinationExists('%s already exists.' % destination)
+            if self.settings['force']:
+                shutil.rmtree(destination)
+            else:
+                raise DestinationExists('%s already exists.' % destination)
 
-        for root, dirnames, filenames in os.walk(self.template_dir):
+        os.makedirs(destination)
+        exit_code = self.create_license(destination, dry_run=True)
+        if exit_code != 0:
+            return
+
+        scripts = self.settings.get('script', None)
+        if scripts and 'prerender' in scripts:
+            self.execute_script(scripts['prerender'], package_name, destination)
+
+        context = self.settings
+        context['package_name'] = package_name
+
+        for Loader in self.settings['template-loaders']:
+            loader = Loader(self.settings, self.template_dir)
+            if loader.template_exists():
+                source = loader.template_path()
+                self.copy_skeleton(source, destination, context=context)
+                loader.cleanup()
+                break
+
+        self.create_license(destination)
+
+        if scripts and 'postrender' in scripts:
+            self.execute_script(scripts['postrender'], package_name, destination)
+
+    def copy_skeleton(self, source, destination, context):
+        for root, dirnames, filenames in os.walk(source):
             for filename in filenames:
                 if filename in self.blacklist:
                     continue
 
                 template = os.path.join(root, filename)
-                relpath = os.path.relpath(template, self.template_dir)
+                relpath = os.path.relpath(template, source)
                 _output = os.path.join(destination, relpath)
                 output = self.render(_output, context)
                 dirname = os.path.dirname(output)
@@ -43,23 +75,6 @@ class PackageCreator(BasePackager):
             context = {}
         return self.renderer.render(content, context)
 
-    def create(self, package_name, destination):
-        exit_code = self.create_license(destination, dry_run=True)
-        if exit_code != 0:
-            return
-
-        scripts = self.settings.get('script', None)
-        if scripts and 'prerender' in scripts:
-            self.execute_script(scripts['prerender'], package_name, destination)
-
-        context = self.settings
-        context['package_name'] = package_name
-        self.copy_skeleton(destination, context=context)
-        self.create_license(destination)
-
-        if scripts and 'postrender' in scripts:
-            self.execute_script(scripts['postrender'], package_name, destination)
-
     def execute_script(self, script, *args):
         _args = (os.path.expanduser(script),) + args
         subprocess.call(' '.join(_args), shell=True, executable="/bin/bash")
